@@ -2,10 +2,7 @@
 Interfacing with the Student Web Service, Department Search.
 """
 import logging
-try:
-    from urllib.parse import urlencode
-except ImportError:
-    from urllib import urlencode
+from urllib.parse import urlencode
 from uw_sws.models import Department
 from uw_sws import get_resource
 
@@ -19,7 +16,7 @@ def get_departments_by_college(college):
     Returns a list of restclients.Department models, for the passed
     College model.
     """
-    url = "%s?%s" % (
+    url = "{}?{}".format(
         dept_search_url_prefix,
         urlencode({"college_abbreviation": college.label}))
     return _json_to_departments(get_resource(url), college)
