@@ -1,14 +1,12 @@
 import json
-import os
 import re
-from datetime import datetime
-from time import strftime
-from dateutil.parser import parse
-from uw_pws.models import Person, Entity
-from uw_sws.exceptions import (InvalidCanvasIndependentStudyCourse,
-                               InvalidCanvasSection)
-from uw_sws.util import (abbr_week_month_day_str, convert_to_begin_of_day,
-                         convert_to_end_of_day)
+from uw_pws.models import Person
+from uw_sws.exceptions import (
+    InvalidCanvasIndependentStudyCourse, InvalidCanvasSection)
+from uw_sws.util import (
+    abbr_week_month_day_str, convert_to_begin_of_day, convert_to_end_of_day,
+    str_to_datetime, str_to_date, date_to_str)
+from uw_sws.dao import sws_now
 from restclients_core import models
 
 SWS_TERM_LABEL = "{year},{quarter}"
@@ -20,19 +18,6 @@ CANVAS_IND_STUDY_COURSE_ID = (
     "{year}-{quarter}-{curr_abbr}-{course_num}-{section_id}-{inst_regid}")
 
 
-def str_to_datetime(s):
-    return parse(s) if (s is not None and len(s)) else None
-
-
-def str_to_date(s):
-    dt = str_to_datetime(s)
-    return dt.date() if dt is not None else None
-
-
-def date_to_str(dt):
-    return str(dt) if dt is not None else None
-
-
 class LastEnrolled(models.Model):
     href = models.CharField(max_length=200)
     quarter = models.CharField(max_length=16)
@@ -91,6 +76,7 @@ class SwsPerson(models.Model):
     gender = models.CharField(max_length=1, null=True, blank=True)
     first_name = models.CharField(max_length=100)
     last_name = models.CharField(max_length=100)
+    pronouns = models.CharField(max_length=140, null=True, blank=True)
     student_name = models.CharField(max_length=255)
     student_number = models.SlugField(max_length=16, null=True, blank=True)
     student_system_key = models.SlugField(max_length=16, null=True, blank=True)
@@ -126,6 +112,7 @@ class SwsPerson(models.Model):
             'email': self.email,
             'first_name': self.first_name,
             'last_name': self.last_name,
+            'pronouns': self.pronouns,
             'student_name': self.student_name,
             'student_number': self.student_number,
             'employee_id': self.employee_id,
@@ -271,7 +258,7 @@ class Term(models.Model):
 
     def is_grading_period_open(self, cmp_dt=None):
         if cmp_dt is None:
-            cmp_dt = datetime.now()
+            cmp_dt = sws_now()
 
         if self.is_summer_quarter():
             open_date = self.aterm_grading_period_open
@@ -284,13 +271,13 @@ class Term(models.Model):
 
     def is_grading_period_past(self, cmp_dt=None):
         if cmp_dt is None:
-            cmp_dt = datetime.now()
+            cmp_dt = sws_now()
         return (self.grade_submission_deadline is None or
                 cmp_dt > self.grade_submission_deadline)
 
     def get_week_of_term(self, cmp_dt=None):
         if cmp_dt is None:
-            cmp_dt = datetime.now()
+            cmp_dt = sws_now()
         return self.get_week_of_term_for_date(cmp_dt)
 
     def get_week_of_term_for_date(self, date):
@@ -633,7 +620,7 @@ class Section(models.Model):
 
     def is_grading_period_open(self, cmp_dt=None):
         if cmp_dt is None:
-            cmp_dt = datetime.now()
+            cmp_dt = sws_now()
 
         if self.is_summer_a_term():
             open_date = self.term.aterm_grading_period_open
@@ -1126,7 +1113,7 @@ class NoticeAttribute(models.Model):
 
     def get_value(self):
         if self.data_type == "date":
-            return self._date_value.strftime("%Y-%m-%d")
+            return date_to_str(self._date_value)
         if self.data_type == "string":
             return self._string_value
         if self.data_type == "url":
