@@ -7,7 +7,6 @@ import re
 from urllib.parse import urlencode
 from decimal import Decimal, InvalidOperation
 from datetime import datetime
-from dateutil.parser import parse
 from uw_sws.models import Registration, ClassSchedule
 from restclients_core.exceptions import DataFailureException
 from restclients_core.cache_manager import (
@@ -15,7 +14,9 @@ from restclients_core.cache_manager import (
     save_all_queued_entries)
 from restclients_core.thread import (
     Thread, GenericPrefetchThread, generic_prefetch)
-from uw_sws import get_resource, UWPWS
+from uw_sws import get_resource
+from uw_sws.person import get_person_by_regid
+from uw_sws.exceptions import ThreadedDataError
 from uw_sws.compat import deprecation
 from uw_sws.thread import SWSThread
 from uw_sws.section import _json_to_section, get_prefetch_for_section_data
@@ -34,7 +35,7 @@ class SWSPersonByRegIDThread(Thread):
         if self.regid is None:
             raise Exception("SWSPersonByRegIDThread must have a regid")
 
-        self.person = UWPWS.get_person_by_regid(self.regid)
+        self.person = get_person_by_regid(self.regid)
 
 
 def get_active_registrations_by_section(section, transcriptable_course=""):
@@ -172,6 +173,7 @@ def get_schedule_by_regid_and_term(regid, term,
     kwargs:
       instructor_reg_id="{instructor regid}"
       (to search the registration with an independent study instructor).
+    Exceptions: DataFailureException, ThreadedDataError
     """
 
     if "include_instructor_not_on_time_schedule" in kwargs:
@@ -270,9 +272,9 @@ def _json_to_stud_reg_schedule(json_data, term, regid,
                                            500,
                                            thread.exception)
             if response.status != 200:
-                raise DataFailureException(thread.url,
-                                           response.status,
-                                           response.data)
+                raise ThreadedDataError(thread.url,
+                                        response.status,
+                                        response.data)
 
             section = _json_to_section(json.loads(response.data), term,
                                        include_instructor_not_on_time_schedule)
