@@ -1,24 +1,35 @@
 from unittest import TestCase
+from datetime import date, datetime
+import pytz
 from uw_sws.util import fdao_sws_override
 from uw_pws.util import fdao_pws_override
 from uw_sws.notice import get_notices_by_regid
-from datetime import date, datetime, timedelta
+from uw_sws.dao import sws_now, SWS_TIMEZONE
+from uw_sws.util import str_to_date
+from datetime import timedelta
+
+
+def date_to_dtime(adate):
+    return str(SWS_TIMEZONE.localize(
+        datetime(year=adate.year, month=adate.month,
+                 day=adate.day)).astimezone(pytz.utc))
 
 
 @fdao_pws_override
 @fdao_sws_override
 class SWSNotice(TestCase):
+
     def test_notice_resource(self):
         notices = get_notices_by_regid("9136CCB8F66711D5BE060004AC494FFE")
         self.assertEquals(len(notices), 17)
 
-        today = date.today()
-        yesterday = today - timedelta(days=1)
-        tomorrow = today + timedelta(days=1)
-        week = today + timedelta(days=2)
-        next_week = today + timedelta(weeks=1)
-        future = today + timedelta(weeks=3)
-        future_end = today + timedelta(weeks=5)
+        today = sws_now().date()
+        yesterday = date_to_dtime(today - timedelta(days=1))
+        tomorrow = date_to_dtime(today + timedelta(days=1))
+        week = date_to_dtime(today + timedelta(days=2))
+        next_week = date_to_dtime(today + timedelta(weeks=1))
+        future = date_to_dtime(today + timedelta(weeks=3))
+        future_end = date_to_dtime(today + timedelta(weeks=5))
 
         notice = notices[0]
         self.assertEquals(notice.notice_category, "StudentALR")
@@ -26,8 +37,7 @@ class SWSNotice(TestCase):
         attribute = notice.attributes[1]
         self.assertEquals(attribute.name, "Date")
         self.assertEquals(attribute.data_type, "date")
-        self.assertEquals(attribute.get_value(),
-                          yesterday.strftime("%Y-%m-%d"))
+        self.assertEquals(attribute.get_value(), yesterday)
 
         notice = notices[1]
         self.assertEquals(notice.notice_category, "StudentDAD")
@@ -38,8 +48,7 @@ class SWSNotice(TestCase):
         attribute = notice.attributes[0]
         self.assertEquals(attribute.name, "Date")
         self.assertEquals(attribute.data_type, "date")
-        self.assertEquals(attribute.get_value(),
-                          future_end.strftime("%Y-%m-%d"))
+        self.assertEquals(attribute.get_value(), future_end)
 
         attribute = notice.attributes[3]
         self.assertEquals(attribute.name, "Quarter")
@@ -63,8 +72,7 @@ class SWSNotice(TestCase):
         attribute = notice.attributes[0]
         self.assertEquals(attribute.name, "Date")
         self.assertEquals(attribute.data_type, "date")
-        self.assertEquals(attribute.get_value(),
-                          next_week.strftime("%Y-%m-%d"))
+        self.assertEquals(attribute.get_value(), next_week)
 
         notice = notices[3]
         self.assertEquals(notice.notice_category, "StudentALR")
@@ -72,7 +80,7 @@ class SWSNotice(TestCase):
         attribute = notice.attributes[0]
         self.assertEquals(attribute.name, "Date")
         self.assertEquals(attribute.data_type, "date")
-        self.assertEquals(attribute.get_value(), week.strftime("%Y-%m-%d"))
+        self.assertEquals(attribute.get_value(), week)
 
         notice = notices[4]
         self.assertEquals(notice.notice_category, "StudentALR")
@@ -80,7 +88,7 @@ class SWSNotice(TestCase):
         attribute = notice.attributes[0]
         self.assertEquals(attribute.name, "Date")
         self.assertEquals(attribute.data_type, "date")
-        self.assertEquals(attribute.get_value(), week.strftime("%Y-%m-%d"))
+        self.assertEquals(attribute.get_value(), week)
 
         notice = notices[4]
         self.assertEquals(notice.notice_category, "StudentALR")
@@ -88,7 +96,7 @@ class SWSNotice(TestCase):
         attribute = notice.attributes[0]
         self.assertEquals(attribute.name, "Date")
         self.assertEquals(attribute.data_type, "date")
-        self.assertEquals(attribute.get_value(), week.strftime("%Y-%m-%d"))
+        self.assertEquals(attribute.get_value(), week)
 
         notice = notices[5]
         self.assertEquals(notice.notice_category, "StudentALR")
@@ -101,8 +109,7 @@ class SWSNotice(TestCase):
         attribute = notice.attributes[0]
         self.assertEquals(attribute.name, "Date")
         self.assertEquals(attribute.data_type, "date")
-        self.assertEquals(attribute.get_value(),
-                          next_week.strftime("%Y-%m-%d"))
+        self.assertEquals(attribute.get_value(), next_week)
 
         notice = notices[8]
         self.assertEquals(notice.notice_category, "StudentDAD")
@@ -110,8 +117,7 @@ class SWSNotice(TestCase):
         attribute = notice.attributes[0]
         self.assertEquals(attribute.name, "Date")
         self.assertEquals(attribute.data_type, "date")
-        self.assertEquals(attribute.get_value(),
-                          next_week.strftime("%Y-%m-%d"))
+        self.assertEquals(attribute.get_value(), next_week)
 
         notice = notices[12]
         self.assertEquals(notice.notice_category, "StudentDAD")
@@ -119,8 +125,7 @@ class SWSNotice(TestCase):
         attribute = notice.attributes[0]
         self.assertEquals(attribute.name, "Date")
         self.assertEquals(attribute.data_type, "date")
-        self.assertEquals(attribute.get_value(),
-                          future_end.strftime("%Y-%m-%d"))
+        self.assertEquals(attribute.get_value(), future_end)
 
         notice = notices[13]
         self.assertEquals(notice.notice_category, "StudentFinAid")
