@@ -1,13 +1,15 @@
 from unittest import TestCase
-from uw_sws.models import Term, date_to_str
+from restclients_core.models import MockHTTP
+from restclients_core.exceptions import DataFailureException
+from uw_sws.exceptions import ThreadedDataError
+from uw_sws.models import Term
 from uw_sws.section import get_section_by_label
 from uw_sws.term import get_term_by_year_and_quarter
 from uw_sws.registration import (
     get_active_registrations_by_section, get_all_registrations_by_section,
     get_schedule_by_regid_and_term)
-from uw_sws.util import fdao_sws_override
+from uw_sws.util import fdao_sws_override, date_to_str
 from uw_pws.util import fdao_pws_override
-from restclients_core.exceptions import DataFailureException
 from decimal import Decimal
 import mock
 
@@ -29,6 +31,7 @@ class SWSTestRegistrations(TestCase):
         reg = get_active_registrations_by_section(section,
                                                   transcriptable_course="all")
         self.assertEqual(len(reg), 2)
+        self.assertEqual(reg[0].person.pronouns, "he/him/his")
 
     def test_all_registrations_by_section(self):
         # Valid section, missing file resources
@@ -263,3 +266,9 @@ class SWSTestRegistrations(TestCase):
             get_term_by_year_and_quarter(2013, "summer"),
             transcriptable_course="all")
         self.assertEqual(len(class_schedule.sections), 0)
+
+    def test_get_schedule_section_error(self):
+        term = Term(quarter="spring", year=2012)
+        self.assertRaises(
+            ThreadedDataError, get_schedule_by_regid_and_term,
+            '9136CCB8F66711D5BE060004AC494FFE', term)
